searchData={"items":[{"type":"module","title":"Loppers","doc":"A code validator for the Elixir-AST.\n\nIt can operate on both white- and blacklists.","ref":"Loppers.html"},{"type":"module","title":"Basic example: - Loppers","doc":"iex> quoted = quote do \"hello\" |> String.upcase |> String.pad_leading(4, \"0\") end\n    iex> whitelist = Loppers.special_forms ++ [{Kernel, :|>}, {String, :upcase}, {String, :pad_leading}]\n    iex> Loppers.validate(quoted, whitelist: whitelist)\n    :ok","ref":"Loppers.html#module-basic-example"},{"type":"function","title":"Loppers.module_support/0","doc":"All functions and macros needed to define modules, functions and set attributes","ref":"Loppers.html#module_support/0"},{"type":"function","title":"Loppers.operators/0","doc":"Convenience list of commonly used operators","ref":"Loppers.html#operators/0"},{"type":"function","title":"Loppers.special_forms/0","doc":"A list of all macros contained in `Kernel.SpecialForms`.\n\nWithout those it's going to be hard to write any elixir code.","ref":"Loppers.html#special_forms/0"},{"type":"function","title":"Loppers.validate/2","doc":"Validates a syntax tree against the given whitelist.\n\nUse `Code.string_to_quoted/2` to get the syntax tree out of source code.\n\nWhen no whitelist is defined, it is assumed that all function calls are ok,\nexcept when they exist in the blacklist.\n\nSupplying both a white- and a blacklist can be useful, for example when you\nwant to allow all functions of a module, except a few that you don't want:\n\n    iex> whitelist = Loppers.special_forms ++ [{Enum, :__all__}]\n    iex> blacklist = [{Enum, :map_reduce}]\n    iex> quoted = quote do Enum.map_reduce([], nil, &({&1, nil})) end\n    iex> Loppers.validate(quoted, [whitelist: whitelist, blacklist: blacklist])\n    {:error, [\n      not_allowed: {{:., [parent_modules: []],\n        [\n          {:__aliases__, [parent_modules: [], alias: false], [:Enum]},\n          :map_reduce\n        ]}, [parent_modules: []],\n       [\n         [],\n         nil,\n         {:&, [parent_modules: []],\n          [{{:&, [parent_modules: []], [1]}, nil}]}\n       ]}\n    ]}","ref":"Loppers.html#validate/2"},{"type":"function","title":"Options - Loppers.validate/2","doc":"* `:whitelist` - a list of `function_ref`s that are allowed in the code\n * `:blacklist` - a list of `function_ref`s that are forbidden in the code","ref":"Loppers.html#validate/2-options"},{"type":"type","title":"Loppers.error/0","doc":"","ref":"Loppers.html#t:error/0"},{"type":"type","title":"Loppers.function_ref/0","doc":"","ref":"Loppers.html#t:function_ref/0"},{"type":"type","title":"Loppers.validate_option/0","doc":"","ref":"Loppers.html#t:validate_option/0"},{"type":"module","title":"Loppers.List","doc":"","ref":"Loppers.List.html"},{"type":"function","title":"Loppers.List.in_list?/2","doc":"","ref":"Loppers.List.html#in_list?/2"},{"type":"module","title":"Loppers.Match","doc":"","ref":"Loppers.Match.html"},{"type":"function","title":"Loppers.Match.is_fn?/1","doc":"","ref":"Loppers.Match.html#is_fn?/1"},{"type":"function","title":"Loppers.Match.list_to_module/1","doc":"","ref":"Loppers.Match.html#list_to_module/1"},{"type":"function","title":"Loppers.Match.matches?/2","doc":"","ref":"Loppers.Match.html#matches?/2"},{"type":"module","title":"Loppers.Validate","doc":"","ref":"Loppers.Validate.html"},{"type":"function","title":"Loppers.Validate.reduce_args/3","doc":"","ref":"Loppers.Validate.html#reduce_args/3"},{"type":"function","title":"Loppers.Validate.validate/3","doc":"","ref":"Loppers.Validate.html#validate/3"},{"type":"module","title":"Loppers.Walk","doc":"","ref":"Loppers.Walk.html"},{"type":"function","title":"Loppers.Walk.function_imported?/3","doc":"Helper to check if a function is imported in a given module.","ref":"Loppers.Walk.html#function_imported?/3"},{"type":"function","title":"Loppers.Walk.gen_meta/2","doc":"Walk callback for collecting metadata like aliases and imports.","ref":"Loppers.Walk.html#gen_meta/2"},{"type":"function","title":"Loppers.Walk.module_functions/2","doc":"Walk callback for collecting metadata like aliases and imports.","ref":"Loppers.Walk.html#module_functions/2"},{"type":"function","title":"Loppers.Walk.recurse/3","doc":"Recursing into the AST. Difference to walk() is that the accumulator will only be changed for current branch.","ref":"Loppers.Walk.html#recurse/3"},{"type":"function","title":"Loppers.Walk.reduce_args/3","doc":"Helper to call walker callback for each args.","ref":"Loppers.Walk.html#reduce_args/3"},{"type":"function","title":"Loppers.Walk.track_parent_modules/2","doc":"","ref":"Loppers.Walk.html#track_parent_modules/2"},{"type":"function","title":"Loppers.Walk.walk/3","doc":"Walking a given ast filling the accumulator using a walker-function.\n\nWalker signature needs to be `walker.(ast, acc)`","ref":"Loppers.Walk.html#walk/3"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,48]}}